@@ -1,10 +1,14 @@
-package Xyzzy::Cookie;
+use utf8;
+use strict;
+use warnings FATAL => 'all';
 
-use Clarity -self;
+package Xyzzy::Cookie;
 
 use Xyzzy::Util qw(uri_escape_auto parse_time);
 use Xyzzy::Header;
 
+use Clarity -self;
+
 field name;
 field value;
 field parameters => {};
@@ -38,13 +42,13 @@ sub setparameters {
 	}
 }
 
-sub setparameter; *setparameter = \&setparameters;
+*setparameter = *setparameters;
 
 sub unsetparameters {
 	delete @{$self->parameters}{map { lc } @_};
 }
 
-sub unsetparameter; *unsetparameter = \&unsetparameters;
+*unsetparameter = *unsetparameters;
 }
 
 sub new {
@@ -120,8 +124,8 @@ Cookie expiry is handled seperately, see the expire() method.
 Create a new Cookie object with the given name and value and any attributes
 you pass. Example:
 
-	# create a https-only cookie called ‘session’ with value ‘foo’
-	my $cookie = new Xyzzy::Cookie(session => 'foo', Secure => 1);
+ # create a https-only cookie called ‘session’ with value ‘foo’
+ my $cookie = new Xyzzy::Cookie(session => 'foo', Secure => 1);
 
 Consider using the bakecookie() method in Xyzzy::Document instead, as it
 will set up the cookie with some useful defaults.
@@ -132,26 +136,26 @@ Set the lifetime for this cookie, expressed as a Xyzzy interval string.
 The value ‘0’ means ‘delete this cookie’. The value C<undef> means ‘keep
 this cookie for the duration of the browser session’. Example:
 
-	# tell the cookie to expire after one hour:
-	$cookie->expire('1h');
+ # tell the cookie to expire after one hour:
+ $cookie->expire('1h');
 
-	# tell the cookie to expire when the browser session ends:
-	$cookie->expire(undef);
-
-	# delete the cookie from the browser:
-	$cookie->expire(0);
+ # tell the cookie to expire when the browser session ends:
+ $cookie->expire(undef);
 
+ # delete the cookie from the browser:
+ $cookie->expire(0);
+ 
 =head2 setparameters($key1, $value1, ...$key2, $value2, ...)
 
 Set the named cookie parameter(s) to the specified values.
 This method is also available as ‘setparameter’ for convenience.
 Example:
 
-	# create a site-wide cookie
-	$cookie->setparameter(Path => '/');
+ # create a site-wide cookie
+ $cookie->setparameter(Path => '/');
 
-	# apply security measures
-	$cookie->setparameters(Secure => 1, HttpOnly => 1);
+ # apply security measures
+ $cookie->setparameters(Secure => 1, HttpOnly => 1);
 
 =head2 unsetparameters($key1...)
 
