@@ -4,51 +4,37 @@ use warnings FATAL => 'all';
 
 package Xyzzy::Crypto;
 
-use MIME::Base64 qw(encode_base64url decode_base64url);
+use MIME::Base64;
 use Encode;
-use Digest::SHA qw(hmac_sha256);
+use Digest::SHA qw(sha256);
 use Crypt::OpenSSL::Random;
 use Time::HiRes qw(time);
-use Xyzzy::Util qw(utf8_testandset utf8_disable);
+use Xyzzy::Util qw(utf8_testandset_inplace);
 
 use Clarity -self;
 
 field cfg;
 field secret => sub { shift->cfg->cryptosecret };
 field jitter => sub { shift->cfg->cryptoclockjitter };
-field seedsource => sub { shift->cfg->cryptoseedsource };
-field seedbytes => sub { shift->cfg->cryptoseedbytes };
-
-our $seedpid = 0; # to detect fork()s
 
 sub random_bytes {
-	my $seedbytes;
-	my $fh;
-	while($seedpid != $$ || !Crypt::OpenSSL::Random::random_status) {
-		$seedbytes //= $self->seedbytes;
-		$fh //= new IO::File($self->seedsource, '<')
-			or die "open(/dev/urandom): $!\n";
-		my $buf = '';
-		while(length($buf) < $seedbytes) {
-			my $r = sysread $fh, $buf, $seedbytes - length($buf), length($buf);
-			die "read(/dev/urandom): $!\n" unless defined $r;
-			die "read(/dev/urandom): EOF\n" unless $r;
-		}
-		Crypt::OpenSSL::Random::random_seed($buf);
-		$seedpid = $$;
-	}
-	return Crypt::OpenSSL::Random::random_bytes(@_)
-		|| die "Insufficient entropy\n";
+	die "Insufficient entropy\n"
+		unless Crypt::OpenSSL::Random::random_status;
+	return Crypt::OpenSSL::Random::random_bytes(@_);
 }
 
 sub random_hex {
-	my $hex = unpack('H*', $self->random_bytes(@_));
-	$hex =~ tr/a-f/A-F/;
+	my $hex = unpack('H*', $self->random_bytes($@));
+	$hex =~ tr/a-z/A-Z/;
 	return $hex;
 }
 
 sub hmac {
-	return hmac_sha256(utf8_disable(@_), $self->secret);
+	my $token = join('', map { my $str = $_; Encode::_utf8_off($str); $str } @_);
+	foreach my $key (@{$self->secret}) {
+		$token = sha256($key . $token);
+	}
+	return $token;
 }
 
 sub create_token_data {
@@ -62,9 +48,7 @@ sub create_token_data {
 
 	my $time = int(time * 1e6);
 	my $salt = $self->random_bytes(16);
-	my $token = @keys && $keys[-1] eq ''
-		? pack('Q>a*(Z*)*', $time, $salt, @keys)
-		: pack('Q>a*a*', $time, $salt, join("\0", @keys));
+	my $token = pack('Q>a*a*', $time, $salt, join("\0", @keys));
 
 	my $hash = $self->hmac($hidden, "\0", $token);
 
@@ -74,7 +58,11 @@ sub create_token_data {
 sub create_token {
 	my ($time, $salt, $raw) = $self->create_token_data(@_);
 
-	return $time, $salt, encode_base64url($raw);
+	my $encoded = encode_base64($raw, '');
+	$encoded =~ s/=+$//;
+	$encoded =~ tr|/+|._|;
+
+	return $time, $salt, $encoded;
 }
 
 sub check_token_data {
@@ -89,9 +77,6 @@ sub check_token_data {
 
 	my ($time, $salt, @keys) = unpack('Q>a16(Z*)*', $token);
 
-	# work around a quirk in unpack():
-	@keys = () if length($token) == 24;
-
 	$time /= 1e6;
 
 	my $now = time;
@@ -102,7 +87,7 @@ sub check_token_data {
 	die "Expired token\n"
 		if $expiry && $time + $expiry < $now;
 
-	utf8_testandset(@keys);
+	utf8_testandset_inplace(@keys);
 
 	if(wantarray) {
 		return $time, $salt, @keys;
@@ -118,9 +103,11 @@ sub check_token {
 		unless defined $token;
 
 	die "Invalid token\n"
-		unless $token =~ /^[a-zA-Z0-9_-]+$/a;
+		unless $token =~ /^[a-zA-Z0-9_.]+$/;
 
-	$token = decode_base64url($token);
+	$token =~ tr|._|/+|;
+	$token .= '=' x -(length($token) % -4);
+	$token = decode_base64($token);
 
 	return $self->check_token_data($hidden, $token, $expiry);
 }
@@ -143,51 +130,36 @@ validation, and a timestamp to allow for expiry.
 Tokens are signed using a passphrase that can be configured using
 Xyzzy::Crypto::Config.
 
-Ascii encoded tokens use a base64 alphabet using A-Za-z0-9 and the
-characters '-' and '_'.
-
-=head2 random_bytes($num)
-
-Returns $num cryptographically random bytes.
-
-=head2 random_hex($num)
-
-Like random_bytes() but returns the result hex-encoded.
-
-=head2 hmac($data ...)
-
-Calculates a HMAC of the specified data, using the configured secret.
-
 =head2 create_token($hidden, ...$public...)
 
-Creates an ascii encoded token from a hidden part and an optional public
-part. Returns the timestamp, salt and (ascii encoded) token string.
+Creates a token from a hidden part and an optional public part.
+Returns the timestamp, salt and (ascii safe) token string.
 
 The public parts may not contain \0 characters (because those are used as
 separators).
 
 Example:
 
-	# Create a session token, tied to the IP-address:
-	my $session = $crypto->create_token('s'.$remote_addr, $uid);
+ # Create a session token, tied to the IP-address:
+ my $session = $crypto->create_token('s'.$remote_addr, $uid);
 
-	# Create an anti-CSRF nonce based on the session:
-	my $nonce = $crypto->create_token('n'.$session);
+ # Create an anti-CSRF nonce based on the session:
+ my $nonce = $crypto->create_token('n'.$session);
 
 In scalar context, this function returns just the token string.
 
 =head2 check_token($hidden, $token, $lifetime)
 
-Checks whether the (ascii encoded) cookie is valid. Returns the timestamp,
-salt and any public data if the token was valid. It will die() if the token
-was invalid somehow. The $hidden parameter must be exactly the same as when
-the token was created or the check will fail. Example:
+Checks whether the cookie is valid. Returns the timestamp, salt and any
+public data if the token was valid. It will die() if the token was invalid
+somehow. The $hidden parameter must be exactly the same as when the token
+was created or the check will fail. Example:
 
-	# check a session token (bound to IP address, valid for one hour)
-	my (undef, undef, $uid) = $crypto->check_token('s'.$remote_addr, $session, 3600);
+ # check a session token (bound to IP address, valid for one hour)
+ my (undef, undef, $uid) = $crypto->check_token('s'.$remote_addr, $session, 3600);
 
-	# same as above, but catch errors more gracefully:
-	my (undef, undef, $uid) = eval { $crypto->check_token('s'.$remote_addr, $session, 3600) }
+ # same as above, but catch errors more gracefully:
+ my (undef, undef, $uid) = eval { $crypto->check_token('s'.$remote_addr, $session, 3600) }
 	or warn "session token: $@";
 
 In scalar context, check_token will return the first public data item. If
