@@ -1,3 +1,7 @@
+use utf8;
+use strict;
+use warnings FATAL => 'all';
+
 package Xyzzy::Document::Config;
 
 use Clarity -self;
@@ -15,13 +19,8 @@ sub set_templatedir {
 	my $dir = shift;
 	die "Missing argument to TemplateDir\n" unless defined $dir;
 	stat $dir;
-	unless(-d _) {
-		if(-e _) {
-			warn "TemplateDir $dir is not a directory\n";
-		} else {
-			warn "TemplateDir $dir doesn't exist\n";
-		}
-	}
+	warn "TemplateDir $dir doesn't exist\n" unless -e _;
+	warn "TemplateDir $dir is not a directory\n" unless -d _;
 	$self->templatedir($dir);
 }
 
@@ -29,13 +28,8 @@ sub set_fragmentdir {
 	my $dir = shift;
 	die "Missing argument to FragmentDir\n" unless defined $dir;
 	stat $dir;
-	unless(-d _) {
-		if(-e _) {
-			warn "FragmentDir $dir is not a directory\n";
-		} else {
-			warn "FragmentDir $dir doesn't exist\n";
-		}
-	}
+	warn "FragmentDir $dir doesn't exist\n" unless -e _;
+	warn "FragmentDir $dir is not a directory\n" unless -d _;
 	$self->fragmentdir($dir);
 }
 
@@ -43,13 +37,8 @@ sub set_contentdir {
 	my $dir = shift;
 	die "Missing argument to ContentDir\n" unless defined $dir;
 	stat $dir;
-	unless(-d _) {
-		if(-e _) {
-			warn "ContentDir $dir is not a directory\n";
-		} else {
-			warn "ContentDir $dir doesn't exist\n";
-		}
-	}
+	warn "ContentDir $dir doesn't exist\n" unless -e _;
+	warn "ContentDir $dir is not a directory\n" unless -d _;
 	$self->contentdir($dir);
 }
 
@@ -57,13 +46,8 @@ sub set_stylesheetdir {
 	my $dir = shift;
 	die "Missing argument to StylesheetDir\n" unless defined $dir;
 	stat $dir;
-	unless(-d _) {
-		if(-e _) {
-			warn "StylesheetDir $dir is not a directory\n";
-		} else {
-			warn "StylesheetDir $dir doesn't exist\n";
-		}
-	}
+	warn "StylesheetDir $dir doesn't exist\n" unless -e _;
+	warn "StylesheetDir $dir is not a directory\n" unless -d _;
 	$self->stylesheetdir($dir);
 }
 
@@ -71,4 +55,4 @@ sub set_cachestylesheets {
 	$self->cache_stylesheets(Xyzzy::parse_bool(shift));
 }
 
-sub set_cachetemplates; *set_cachetemplates = \&set_cachestylesheets;
+*set_cachetemplates = \&set_cachestylesheets;
