@@ -14,14 +14,13 @@ field specific => {};
 field fallback => sub { new Xyzzy::Fail(cfg => shift, code => 404) };
 
 sub handle {
-	my $ctx = shift;
+	my $req = new Xyzzy::ReST::Request(cfg => $self, ctx => shift);
 
-	my $path = $ctx->path_components;
+	my $path = $req->path_components;
 
-	return $self->handler->handle($ctx, @_)
+	return $self->handler->handle($req, @_)
 		unless @$path;
 
-	my $req = new Xyzzy::ReST::Request(cfg => $self, ctx => $ctx);
 	my $pairs = $req->pairs;
 
 	my $entity = $pairs->[-2];
@@ -30,7 +29,7 @@ sub handle {
 	my $handlers = defined $value ? $self->specific : $self->generic;
 
 	my $handler = $handlers->{$entity};
-	return $self->fallback->handle($ctx, @_)
+	return $self->fallback->handle($req, @_)
 		unless $handler;
 
 	return $handler->handle($req, @_);
