@@ -4,7 +4,7 @@ use warnings FATAL => 'all';
 
 package Xyzzy::Response;
 
-use Encode qw(_utf8_off);
+use Encode qw(is_utf8 encode_utf8);
 
 use Xyzzy::Header;
 use Xyzzy::Cookie;
@@ -24,11 +24,11 @@ field headers => {
 
 field content;
 
-my %case = (xss => 'XSS', http => 'HTTP', www => 'WWW', ua => 'UA');
+my %case = (xss => 'XSS', http => 'HTTP', www => 'WWW');
 
 sub canonicalheader() {
 	my $key = $_[0];
-	confess("Invalid header name '$key'")
+	confess "Invalid header name '$key'"
 		unless Xyzzy::Header::istoken($key);
 	$key = lc $key;
 	$key =~ s{([a-z]+)}{$case{$1} // ucfirst($1)}ge;
@@ -95,35 +95,30 @@ sub as_cgi {
 
 	my $content = $self->content;
 
+	$content = encode_utf8($content)
+		if is_utf8($content);
+
 	$self->setheader('Content-Length', length($content));
 
 	my $status = $self->status;
 	push @output, "Status: $status\r\n";
 	my $headers = $self->headers;
 	while(my ($key, $vals) = each(%$headers)) {
-		my $separate;
+		my $seperate;
 		if(@$vals > 1) {
 			foreach my $val (@$vals) {
-				$separate = 1
+				$seperate = 1
 					unless Xyzzy::Header::istoken($val);
 			}
 		}
-		if($separate) {
+		if($seperate) {
 			foreach my $val (@$vals) {
 				push @output, $key, ': ', $val, "\r\n";
 			}
 		} else {
-			my %uniq;
-			push @output, $key, ': ', join(', ', grep { !$uniq{lc $_}++ } @$vals), "\r\n";
+			push @output, $key, ': ', join(', ', @$vals), "\r\n";
 		}
 	}
 	push @output, "\r\n", $content;
-
-	# headers and content are supposed to be byte encoded.
-	# in the case where something turns out to be character encoded,
-	# send it out as utf-8 bytes.
-	foreach(@output) {
-		_utf8_off($_);
-	}
 	return \@output;
 }
