@@ -8,8 +8,8 @@ use Encode;
 use URI::Escape;
 use Exporter 'import';
 
-our @EXPORT_OK = qw(iso8601 iso8601_date iso8601_strict utf8_testandset_inplace utf8_testandset utf8_disable_inplace utf8_disable uri_escape_auto uri_escape_plus uri_unescape_plus htmlentities parse_time parse_size parse_bool parse_path);
-our %EXPORT_TAGS = (all => \@EXPORT_OK);
+our @EXPORT_OK = qw(iso8601 iso8601_date iso8601_strict utf8_testandset_inplace utf8_testandset uri_escape_auto uri_escape_plus uri_unescape_plus htmlentities parse_time parse_size parse_bool);
+our %EXPORT_TAGS = (all => \@EXPORT_OK);  
 
 sub iso8601 {
 	my ($sec, $min, $hour, $mday, $mon, $year) = @_;
@@ -29,74 +29,20 @@ sub iso8601_strict {
 		$year + 1900, $mon + 1, $mday, $hour, $min, $sec)
 }
 
-# upgrade to UTF-8 if possible, without changing any bytes (deprecated)
 sub utf8_testandset_inplace {
 	foreach my $val (@_) {
-		next unless defined $val;
+		# upgrade to UTF-8 if possible, without changing any bytes
 		Encode::_utf8_on($val);
 		Encode::_utf8_off($val) unless utf8::valid($val);
 	}
 	return;
 }
 
-# upgrade to UTF-8 if possible, without changing any bytes
 sub utf8_testandset {
-	my $wantlist = wantarray;
-	if($wantlist) { # list context
-		return map {
-			my $val = $_; # make sure we work on a copy
-			if(defined $val) {
-				Encode::_utf8_on($val);
-				Encode::_utf8_off($val) unless utf8::valid($val);
-			}
-			$val
-		} @_;
-	} elsif(defined $wantlist) { # scalar context
-		my $val = pop;
-		if(defined $val) {
-			Encode::_utf8_on($val);
-			Encode::_utf8_off($val) unless utf8::valid($val);
-		}
-		return $val;
-	} else { # void context
-		foreach my $val (@_) {
-			if(defined $val) {
-				Encode::_utf8_on($val);
-				Encode::_utf8_off($val) unless utf8::valid($val);
-			}
-		}
-	}
-	return;
-}
-
-# undo utf8_testandset_inplace (deprecated)
-sub utf8_disable_inplace {
-	foreach my $val (@_) {
-		next unless defined $val;
-		Encode::_utf8_off($val);
-	}
-	return;
-}
-
-# undo utf8_testandset
-sub utf8_disable {
-	my $wantlist = wantarray;
-	if($wantlist) { # list context
-		return map {
-			my $val = $_; # make sure we work on a copy
-			Encode::_utf8_off($val) if defined $val;
-			$val
-		} @_;
-	} elsif(defined $wantlist) { # scalar context
-		my $val = pop;
-		Encode::_utf8_off($val) if defined $val;
-		return $val;
-	} else { # void context
-		foreach my $val (@_) {
-			Encode::_utf8_off($val) if defined $val;
-		}
-	}
-	return;
+	my $str = shift;
+	return undef unless defined $str;
+	utf8_testandset_inplace($str);
+	return $str;
 }
 
 sub uri_escape_auto {
@@ -147,7 +93,7 @@ sub uri_unescape_plus {
 		h => 3600,
 		d => 86400,
 		w => 604800,
-		l => 31 * 86400,
+		m => 31 * 86400,
 		q => 92 * 86400,
 		y => int(365.2425 * 86400),
 	);
@@ -195,11 +141,3 @@ sub parse_bool {
 	return 0 if /^(?:0|n|no|false|off|disabled?)$/i;
 	die "unknown boolean value '$_'\n";
 }
-
-sub parse_path {
-	return [map {
-		utf8_testandset($_);
-	} grep {
-		$_ ne ''
-	} split(qr{/+}, shift)];
-}
